# Infernet ML

Ritual provides easy-to-use abstractions for users to create AI/ML workflows that can be
deployed on Infernet nodes.
The [`infernet-ml`](https://github.com/ritual-net/infernet-ml) library is a Python SDK
that provides a set of tools and extendable classes for creating and
deploying machine learning workflows. It is designed to be easy to use, and provides a
consistent interface for data pre-processing, inference, and post-processing of data.

## Installation

**Via `uv`:**

``` bash
uv pip install infernet-ml
```

**Via `pip`:**

``` bash
pip install infernet-ml
```

For more information, see
the [documentation website](https://infernet-ml.docs.ritual.net).
